@@ -1,5 +1,5 @@
 #ggplot codes
-geomCode<-function(type,data,x,y,ymin=NULL,ymax=NULL,group=NULL,color=NULL,linetype=NULL,shape=NULL,type_UGC=NULL){
+geomCode<-function(type,data,x,y,ymin=NULL,ymax=NULL,group=NULL,color=NULL,fill=NULL,linetype=NULL,shape=NULL,type_UGC=NULL){
   # browser()
 	# if (is.null(data)||!is.null(x)||!is.null(y)||!is.null(ymin))
   if (is.null(data)&&is.null(x)&&is.null(y)&&is.null(ymin))
@@ -15,13 +15,14 @@ geomCode<-function(type,data,x,y,ymin=NULL,ymax=NULL,group=NULL,color=NULL,linet
 	ymax<-GetYText(ymax)
 	group<-GetGroupText(group)
 	color<-GetGroupText(color)
+  fill<-GetGroupText(fill)
 	linetype<-GetGroupText(linetype)
 	shape<-GetGroupText(shape)
 	if(is.null(x)&&is.null(y)&&(is.null(ymin)&&is.null(ymax))){return()}else{
   	if(!is.null(y)||!(is.null(ymin)&&is.null(ymax))){
-  	  geomCode<-SetEveryY(type,data,x,y,ymin,ymax,group,color,linetype,shape,type_UGC)
+  	  geomCode<-SetEveryY(type,data,x,y,ymin,ymax,group,color,fill,linetype,shape,type_UGC)
   	}else{
-  	  geomCode<-GetGeomCode(type,data,x,y,ymin,ymax,group,color,linetype,shape,type_UGC)
+  	  geomCode<-GetGeomCode(type,data,x,y,ymin,ymax,group,color,fill,linetype,shape,type_UGC)
   	}
 	}
 	return(geomCode)
@@ -29,27 +30,27 @@ geomCode<-function(type,data,x,y,ymin=NULL,ymax=NULL,group=NULL,color=NULL,linet
 }
 
 #anasisy Y
-SetEveryY<-function(type,data,x,y,ymin=NULL,ymax=NULL,group=NULL,color=NULL,linetype=NULL,shape=NULL,type_UGC=NULL){
+SetEveryY<-function(type,data,x,y,ymin=NULL,ymax=NULL,group=NULL,color=NULL,fill=NULL,linetype=NULL,shape=NULL,type_UGC=NULL){
   if(is.null(y)&&(is.null(ymin)&&is.null(ymax)))
     return()
   if(!is.null(y)){
     j<-1L
     geomCode<-c()
     for(i in y){
-      geomCode[j]<-GetGeomCode(type,data,x,i,ymin,ymax,group,color,linetype,shape,type_UGC)
+      geomCode[j]<-GetGeomCode(type,data,x,i,ymin,ymax,group,color,fill,linetype,shape,type_UGC)
       j<-j+1
     }
     geomCodes<-paste(geomCode,collapse ="+")
     geomCodes
   }else{
-    GetGeomCode(type,data,x,y,ymin,ymax,group,color,linetype,shape,type_UGC)
+    GetGeomCode(type,data,x,y,ymin,ymax,group,color,fill,linetype,shape,type_UGC)
   }
 }
 
 
 
 #Get ggplot Geom Codes
-GetGeomCode<-function(type,data,x,y,ymin=NULL,ymax=NULL,group=NULL,color=NULL,linetype=NULL,shape=NULL,type_UGC=NULL){
+GetGeomCode<-function(type,data,x,y,ymin=NULL,ymax=NULL,group=NULL,color=NULL,fill=NULL,linetype=NULL,shape=NULL,type_UGC=NULL){
   if(is.null(type))
     return()
   # browser()
@@ -60,7 +61,7 @@ GetGeomCode<-function(type,data,x,y,ymin=NULL,ymax=NULL,group=NULL,color=NULL,li
     type_UGC_item <- type_UGC[type_UGC$geom_type %in% i,]
     # browser()
     ###get aes Code 02
-    ls1<-paste1(sep=",",x,y,ymin,ymax,group,color,linetype,shape,type_UGC_item$geom_Additional_AesCode)
+    ls1<-paste1(sep=",",x,y,ymin,ymax,group,color,fill,linetype,shape,type_UGC_item$geom_Additional_AesCode)
     aes<-paste(sep="","aes","(",ls1,")")
     
     ##get code
